@@ -26,6 +26,39 @@ class CbsClient(AbstractClient):
     _service = 'cbs'
 
 
+    def ApplyDiskBackup(self, request):
+        """本接口（ApplyDiskBackup）用于回滚备份点到原云硬盘。
+
+        * 仅支持回滚到原云硬盘上。对于数据盘备份点，如果您需要复制备份点数据到其它云硬盘上，请先使用 CreateSnapshot 将备份点转换为快照，然后使用 CreateDisks 接口创建新的弹性云硬盘，将快照数据复制到新购云硬盘上。
+        * 用于回滚的备份点必须处于NORMAL状态。备份点状态可以通过DescribeDiskBackups接口查询，见输出参数中BackupState字段解释。
+        * 如果是弹性云硬盘，则云硬盘必须处于未挂载状态，云硬盘挂载状态可以通过DescribeDisks接口查询，见Attached字段解释；如果是随实例一起购买的非弹性云硬盘，则实例必须处于关机状态，实例状态可以通过DescribeInstancesStatus接口查询。
+
+        :param request: Request instance for ApplyDiskBackup.
+        :type request: :class:`tencentcloud.cbs.v20170312.models.ApplyDiskBackupRequest`
+        :rtype: :class:`tencentcloud.cbs.v20170312.models.ApplyDiskBackupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ApplyDiskBackup", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ApplyDiskBackupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ApplySnapshot(self, request):
         """本接口（ApplySnapshot）用于回滚快照到原云硬盘。
 
@@ -40,7 +73,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ApplySnapshot", params)
+            headers = request.headers
+            body = self.call("ApplySnapshot", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ApplySnapshotResponse()
@@ -71,7 +105,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AttachDisks", params)
+            headers = request.headers
+            body = self.call("AttachDisks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AttachDisksResponse()
@@ -102,7 +137,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("BindAutoSnapshotPolicy", params)
+            headers = request.headers
+            body = self.call("BindAutoSnapshotPolicy", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.BindAutoSnapshotPolicyResponse()
@@ -120,6 +156,38 @@ class CbsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CopySnapshotCrossRegions(self, request):
+        """本接口（CopySnapshotCrossRegions）用于快照跨地域复制。
+
+        * 本接口为异步接口，当跨地域复制的请求下发成功后会返回一个新的快照ID，此时快照未立即复制到目标地域，可请求目标地域的[DescribeSnapshots](/document/product/362/15647)接口查询新快照的状态，判断是否复制完成。如果快照的状态为“NORMAL”，表示快照复制完成。
+        * 本接口实现的快照跨地域复制操作将产生跨地域流量，预计2022年第三季度会针对此功能进行商业化计费；请留意后续站内信公告，避免产生预期外扣费。
+
+        :param request: Request instance for CopySnapshotCrossRegions.
+        :type request: :class:`tencentcloud.cbs.v20170312.models.CopySnapshotCrossRegionsRequest`
+        :rtype: :class:`tencentcloud.cbs.v20170312.models.CopySnapshotCrossRegionsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CopySnapshotCrossRegions", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CopySnapshotCrossRegionsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateAutoSnapshotPolicy(self, request):
         """本接口（CreateAutoSnapshotPolicy）用于创建定期快照策略。
 
@@ -133,7 +201,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateAutoSnapshotPolicy", params)
+            headers = request.headers
+            body = self.call("CreateAutoSnapshotPolicy", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateAutoSnapshotPolicyResponse()
@@ -165,7 +234,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateDisks", params)
+            headers = request.headers
+            body = self.call("CreateDisks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateDisksResponse()
@@ -188,6 +258,7 @@ class CbsClient(AbstractClient):
 
         * 只有具有快照能力的云硬盘才能创建快照。云硬盘是否具有快照能力可由[DescribeDisks](/document/product/362/16315)接口查询，见SnapshotAbility字段。
         * 可创建快照数量限制见[产品使用限制](https://cloud.tencent.com/doc/product/362/5145)。
+        * 当前支持将备份点转化为普通快照，转化之后可能会收取快照使用费用，备份点不保留，其占用的备份点配额也将被释放。
 
         :param request: Request instance for CreateSnapshot.
         :type request: :class:`tencentcloud.cbs.v20170312.models.CreateSnapshotRequest`
@@ -196,7 +267,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateSnapshot", params)
+            headers = request.headers
+            body = self.call("CreateSnapshot", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateSnapshotResponse()
@@ -226,7 +298,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteAutoSnapshotPolicies", params)
+            headers = request.headers
+            body = self.call("DeleteAutoSnapshotPolicies", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteAutoSnapshotPoliciesResponse()
@@ -244,6 +317,35 @@ class CbsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteDiskBackups(self, request):
+        """批量删除指定的云硬盘备份点。
+
+        :param request: Request instance for DeleteDiskBackups.
+        :type request: :class:`tencentcloud.cbs.v20170312.models.DeleteDiskBackupsRequest`
+        :rtype: :class:`tencentcloud.cbs.v20170312.models.DeleteDiskBackupsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteDiskBackups", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteDiskBackupsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteSnapshots(self, request):
         """本接口（DeleteSnapshots）用于删除快照。
 
@@ -257,7 +359,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteSnapshots", params)
+            headers = request.headers
+            body = self.call("DeleteSnapshots", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteSnapshotsResponse()
@@ -288,7 +391,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAutoSnapshotPolicies", params)
+            headers = request.headers
+            body = self.call("DescribeAutoSnapshotPolicies", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAutoSnapshotPoliciesResponse()
@@ -316,7 +420,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDiskAssociatedAutoSnapshotPolicy", params)
+            headers = request.headers
+            body = self.call("DescribeDiskAssociatedAutoSnapshotPolicy", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDiskAssociatedAutoSnapshotPolicyResponse()
@@ -334,6 +439,38 @@ class CbsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeDiskBackups(self, request):
+        """本接口（DescribeDiskBackups）用于查询备份点的详细信息。
+
+        根据备份点ID、创建备份点的云硬盘ID、创建备份点的云硬盘类型等对结果进行过滤，不同条件之间为与(AND)的关系，过滤信息详细请见过滤器Filter。
+        如果参数为空，返回当前用户一定数量（Limit所指定的数量，默认为20）的备份点列表。
+
+        :param request: Request instance for DescribeDiskBackups.
+        :type request: :class:`tencentcloud.cbs.v20170312.models.DescribeDiskBackupsRequest`
+        :rtype: :class:`tencentcloud.cbs.v20170312.models.DescribeDiskBackupsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDiskBackups", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeDiskBackupsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeDiskConfigQuota(self, request):
         """本接口（DescribeDiskConfigQuota）用于查询云硬盘配额。
 
@@ -344,7 +481,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDiskConfigQuota", params)
+            headers = request.headers
+            body = self.call("DescribeDiskConfigQuota", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDiskConfigQuotaResponse()
@@ -372,7 +510,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDiskOperationLogs", params)
+            headers = request.headers
+            body = self.call("DescribeDiskOperationLogs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDiskOperationLogsResponse()
@@ -390,6 +529,38 @@ class CbsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeDiskStoragePool(self, request):
+        """本接口（DescribeDiskStoragePool）查询用户的云硬盘独享集群列表。
+
+        * 可以根据独享集群ID(CdcId)、可用区(zone)等信息来查询和过滤云硬盘独享集群详细信息，不同的过滤条件之间为与(AND)的关系，过滤信息详细请见过滤器`Filter`。
+        * 如果参数为空，返回当前用户一定数量（`Limit`所指定的数量，默认为20）的云硬盘独享集群列表。
+
+        :param request: Request instance for DescribeDiskStoragePool.
+        :type request: :class:`tencentcloud.cbs.v20170312.models.DescribeDiskStoragePoolRequest`
+        :rtype: :class:`tencentcloud.cbs.v20170312.models.DescribeDiskStoragePoolResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDiskStoragePool", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeDiskStoragePoolResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeDisks(self, request):
         """本接口（DescribeDisks）用于查询云硬盘列表。
 
@@ -403,7 +574,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDisks", params)
+            headers = request.headers
+            body = self.call("DescribeDisks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDisksResponse()
@@ -433,7 +605,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeInstancesDiskNum", params)
+            headers = request.headers
+            body = self.call("DescribeInstancesDiskNum", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeInstancesDiskNumResponse()
@@ -463,7 +636,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSnapshotOperationLogs", params)
+            headers = request.headers
+            body = self.call("DescribeSnapshotOperationLogs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSnapshotOperationLogsResponse()
@@ -491,7 +665,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSnapshotSharePermission", params)
+            headers = request.headers
+            body = self.call("DescribeSnapshotSharePermission", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSnapshotSharePermissionResponse()
@@ -522,7 +697,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSnapshots", params)
+            headers = request.headers
+            body = self.call("DescribeSnapshots", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSnapshotsResponse()
@@ -553,7 +729,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DetachDisks", params)
+            headers = request.headers
+            body = self.call("DetachDisks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DetachDisksResponse()
@@ -581,7 +758,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetSnapOverview", params)
+            headers = request.headers
+            body = self.call("GetSnapOverview", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetSnapOverviewResponse()
@@ -599,6 +777,68 @@ class CbsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def InitializeDisks(self, request):
+        """重新初始化云硬盘至云硬盘初始创建时的状态。使用云硬盘的重新初始化功能时需要注意以下4点：
+        1. 如果云硬盘是由快照创建的，则重新初始化会通过此快照重新回滚此云硬盘，即将云硬盘恢复为与快照一致的状态；
+        2. 如果云硬盘不是通过快照创建的，则重新初始化会清空此云硬盘的数据；请在重新初始化云硬盘前检查并备份必要的数据；
+        3. 当前仅未挂载的、非共享属性的数据盘云硬盘支持重新初始化；
+        4. 当创建此云硬盘的原始快照被删除时，不再支持重新初始化此云硬盘。
+
+        :param request: Request instance for InitializeDisks.
+        :type request: :class:`tencentcloud.cbs.v20170312.models.InitializeDisksRequest`
+        :rtype: :class:`tencentcloud.cbs.v20170312.models.InitializeDisksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("InitializeDisks", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.InitializeDisksResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def InquirePriceModifyDiskBackupQuota(self, request):
+        """本接口（InquirePricePriceModifyDiskBackupQuota）用于修改云硬盘备份点配额询价。
+
+        :param request: Request instance for InquirePriceModifyDiskBackupQuota.
+        :type request: :class:`tencentcloud.cbs.v20170312.models.InquirePriceModifyDiskBackupQuotaRequest`
+        :rtype: :class:`tencentcloud.cbs.v20170312.models.InquirePriceModifyDiskBackupQuotaResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("InquirePriceModifyDiskBackupQuota", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.InquirePriceModifyDiskBackupQuotaResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def InquirePriceModifyDiskExtraPerformance(self, request):
         """本接口（InquirePriceModifyDiskExtraPerformance）用于调整云硬盘额外性能询价。
 
@@ -609,7 +849,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquirePriceModifyDiskExtraPerformance", params)
+            headers = request.headers
+            body = self.call("InquirePriceModifyDiskExtraPerformance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquirePriceModifyDiskExtraPerformanceResponse()
@@ -639,7 +880,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquiryPriceCreateDisks", params)
+            headers = request.headers
+            body = self.call("InquiryPriceCreateDisks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquiryPriceCreateDisksResponse()
@@ -671,7 +913,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquiryPriceRenewDisks", params)
+            headers = request.headers
+            body = self.call("InquiryPriceRenewDisks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquiryPriceRenewDisksResponse()
@@ -701,7 +944,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquiryPriceResizeDisk", params)
+            headers = request.headers
+            body = self.call("InquiryPriceResizeDisk", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquiryPriceResizeDiskResponse()
@@ -732,7 +976,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAutoSnapshotPolicyAttribute", params)
+            headers = request.headers
+            body = self.call("ModifyAutoSnapshotPolicyAttribute", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyAutoSnapshotPolicyAttributeResponse()
@@ -762,7 +1007,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDiskAttributes", params)
+            headers = request.headers
+            body = self.call("ModifyDiskAttributes", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDiskAttributesResponse()
@@ -780,6 +1026,35 @@ class CbsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyDiskBackupQuota(self, request):
+        """此接口 (ModifyDiskBackupQuota) 用于修改云硬盘备份点配额。
+
+        :param request: Request instance for ModifyDiskBackupQuota.
+        :type request: :class:`tencentcloud.cbs.v20170312.models.ModifyDiskBackupQuotaRequest`
+        :rtype: :class:`tencentcloud.cbs.v20170312.models.ModifyDiskBackupQuotaResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyDiskBackupQuota", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyDiskBackupQuotaResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyDiskExtraPerformance(self, request):
         """本接口（ModifyDiskExtraPerformance）用于调整云硬盘额外的性能。
 
@@ -792,7 +1067,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDiskExtraPerformance", params)
+            headers = request.headers
+            body = self.call("ModifyDiskExtraPerformance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDiskExtraPerformanceResponse()
@@ -826,7 +1102,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDisksChargeType", params)
+            headers = request.headers
+            body = self.call("ModifyDisksChargeType", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDisksChargeTypeResponse()
@@ -854,7 +1131,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDisksRenewFlag", params)
+            headers = request.headers
+            body = self.call("ModifyDisksRenewFlag", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDisksRenewFlagResponse()
@@ -885,7 +1163,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifySnapshotAttribute", params)
+            headers = request.headers
+            body = self.call("ModifySnapshotAttribute", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifySnapshotAttributeResponse()
@@ -919,7 +1198,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifySnapshotsSharePermission", params)
+            headers = request.headers
+            body = self.call("ModifySnapshotsSharePermission", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifySnapshotsSharePermissionResponse()
@@ -950,7 +1230,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RenewDisk", params)
+            headers = request.headers
+            body = self.call("RenewDisk", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RenewDiskResponse()
@@ -981,7 +1262,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ResizeDisk", params)
+            headers = request.headers
+            body = self.call("ResizeDisk", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ResizeDiskResponse()
@@ -1004,7 +1286,7 @@ class CbsClient(AbstractClient):
 
         * 不再使用的云盘，可通过本接口主动退还。
         * 本接口支持退还预付费云盘和按小时后付费云盘。按小时后付费云盘可直接退还，预付费云盘需符合退还规则。
-        * 支持批量操作，每次请求批量云硬盘的上限为50。如果批量云盘存在不允许操作的，请求会以特定错误码返回。
+        * 支持批量操作，每次请求批量云硬盘的上限为100。如果批量云盘存在不允许操作的，请求会以特定错误码返回。
 
         :param request: Request instance for TerminateDisks.
         :type request: :class:`tencentcloud.cbs.v20170312.models.TerminateDisksRequest`
@@ -1013,7 +1295,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("TerminateDisks", params)
+            headers = request.headers
+            body = self.call("TerminateDisks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.TerminateDisksResponse()
@@ -1044,7 +1327,8 @@ class CbsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UnbindAutoSnapshotPolicy", params)
+            headers = request.headers
+            body = self.call("UnbindAutoSnapshotPolicy", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UnbindAutoSnapshotPolicyResponse()
