@@ -87,7 +87,7 @@ class DtsClient(AbstractClient):
 
 
     def CreateCheckSyncJob(self, request):
-        """校验同步任务，检查必要参数和周边
+        """校验同步任务，检查必要参数和周边配置。
 
         :param request: Request instance for CreateCheckSyncJob.
         :type request: :class:`tencentcloud.dts.v20211206.models.CreateCheckSyncJobRequest`
@@ -350,7 +350,7 @@ class DtsClient(AbstractClient):
 
 
     def DescribeMigrateDBInstances(self, request):
-        """本接口用于查询支持迁移的是云数据库实例
+        """本接口用于查询支持迁移的云数据库实例
 
         :param request: Request instance for DescribeMigrateDBInstances.
         :type request: :class:`tencentcloud.dts.v20211206.models.DescribeMigrateDBInstancesRequest`
@@ -497,7 +497,7 @@ class DtsClient(AbstractClient):
 
 
     def DestroyMigrateJob(self, request):
-        """下线删除数据迁移任务。计费任务必须先调用隔离(IsolateMigrateJob)接口，且只有是**已隔离**状态下，才能调用此接口销毁任务。对于不计费任务，调用隔离(IsolateMigrateJob)接口删除任务操作。
+        """下线数据迁移任务。计费任务必须先调用隔离(IsolateMigrateJob)接口，且只有是**已隔离**状态下，才能调用此接口销毁任务。对于不计费任务，调用隔离(IsolateMigrateJob)接口删除任务操作。
 
         :param request: Request instance for DestroyMigrateJob.
         :type request: :class:`tencentcloud.dts.v20211206.models.DestroyMigrateJobRequest`
@@ -845,7 +845,7 @@ class DtsClient(AbstractClient):
 
 
     def ResumeMigrateJob(self, request):
-        """重试数据迁移任务，针对redis在迁移在失败情况下的重试操作，注意：此操作跳过校验阶段，直接重新发起任务，相当于从StartMigrationJob开始执行。调用此接口后可通过查询迁移服务列表接口`DescribeMigrationJobs`来查询当前任务状态。
+        """重试数据迁移任务，针对异常情况可进行重试，对于redis在失败时也可重试。注意：此操作跳过校验阶段，直接重新发起任务，相当于从StartMigrationJob开始执行。调用此接口后可通过查询迁移服务列表接口`DescribeMigrationJobs`来查询当前任务状态。
 
         :param request: Request instance for ResumeMigrateJob.
         :type request: :class:`tencentcloud.dts.v20211206.models.ResumeMigrateJobRequest`
