@@ -30,12 +30,12 @@ class AssessQualityRequest(AbstractModel):
 • 图片格式：PNG、JPG、JPEG。 
 • 图片大小：所下载图片经Base64编码后不超过4M。图片下载时间不超过3秒。 
 建议：
-• 图片像素：大于50*50像素，否则影响识别效果； 
-• 长宽比：长边：短边<5； 
+• 图片像素：大于50*50像素，否则影响识别效果。 
+• 长宽比：长边：短边<5。
 接口响应时间会受到图片下载时间的影响，建议使用更可靠的存储服务，推荐将图片存储在腾讯云COS。
         :type ImageUrl: str
-        :param ImageBase64: 图片经过base64编码的内容。最大不超过4M。与ImageUrl同时存在时优先使用ImageUrl字段。
-**注意：图片需要base64编码，并且要去掉编码头部。**
+        :param ImageBase64: 图片经过Base64编码的内容。最大不超过4M。与ImageUrl同时存在时优先使用ImageUrl字段。
+**注意：图片需要Base64编码，并且要去掉编码头部。**
         :type ImageBase64: str
         """
         self.ImageUrl = None
@@ -555,25 +555,25 @@ class CropImageRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param Width: 需要裁剪区域的宽度，与Height共同组成所需裁剪的图片宽高比例；
-输入数字请大于0、小于图片宽度的像素值；
+        :param Width: 需要裁剪区域的宽度，与Height共同组成所需裁剪的图片宽高比例。
+输入数字请大于0、小于图片宽度的像素值。
         :type Width: int
-        :param Height: 需要裁剪区域的高度，与Width共同组成所需裁剪的图片宽高比例；
-输入数字请请大于0、小于图片高度的像素值；
+        :param Height: 需要裁剪区域的高度，与Width共同组成所需裁剪的图片宽高比例。
+输入数字请请大于0、小于图片高度的像素值。
 宽高比例（Width : Height）会简化为最简分数，即如果Width输入10、Height输入20，会简化为1：2。
-Width : Height建议取值在[1, 2.5]之间，超过这个范围可能会影响效果；
+Width : Height建议取值在[1, 2.5]之间，超过这个范围可能会影响效果。
         :type Height: int
         :param ImageUrl: 图片URL地址。 
 图片限制： 
 • 图片格式：PNG、JPG、JPEG。 
 • 图片大小：所下载图片经Base64编码后不超过4M。图片下载时间不超过3秒。 
 建议：
-• 图片像素：大于50*50像素，否则影响识别效果； 
-• 长宽比：长边：短边<5； 
+• 图片像素：大于50*50像素，否则影响识别效果。
+• 长宽比：长边：短边<5。 
 接口响应时间会受到图片下载时间的影响，建议使用更可靠的存储服务，推荐将图片存储在腾讯云COS。
         :type ImageUrl: str
-        :param ImageBase64: 图片经过base64编码的内容。最大不超过4M。与ImageUrl同时存在时优先使用ImageUrl字段。
-**注意：图片需要base64编码，并且要去掉编码头部。**
+        :param ImageBase64: 图片经过Base64编码的内容。最大不超过4M。与ImageUrl同时存在时优先使用ImageUrl字段。
+注意：图片需要Base64编码，并且要去掉编码头部。
         :type ImageBase64: str
         """
         self.Width = None
@@ -1506,12 +1506,12 @@ class EnhanceImageRequest(AbstractModel):
 • 图片格式：PNG、JPG、JPEG。 
 • 图片大小：所下载图片经Base64编码后不超过4M。图片下载时间不超过3秒。 
 建议：
-• 图片像素：大于50*50像素，最大不超过250万像素，否则影响识别效果； 
-• 长宽比：长边：短边<5； 
+• 图片像素：大于50*50像素，最大不超过250万像素，否则影响识别效果。 
+• 长宽比：长边：短边<5。 
 接口响应时间会受到图片下载时间的影响，建议使用更可靠的存储服务，推荐将图片存储在腾讯云COS。
         :type ImageUrl: str
-        :param ImageBase64: 支持PNG、JPG、JPEG、BMP，不支持 GIF 图片。图片经过base64编码的内容。最大不超过4M。与ImageUrl同时存在时优先使用ImageUrl字段。
-**注意：图片需要base64编码，并且要去掉编码头部。**
+        :param ImageBase64: 支持PNG、JPG、JPEG、BMP，不支持 GIF 图片。图片经过Base64编码的内容。最大不超过4M。与ImageUrl同时存在时优先使用ImageUrl字段。
+注意：图片需要Base64编码，并且要去掉编码头部。
         :type ImageBase64: str
         """
         self.ImageUrl = None
